Stan Math Library: stan::math::cvodes_ode_data< F, T_initial, T_param > Class Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Static Public Member Functions | List of all members
stan::math::cvodes_ode_data< F, T_initial, T_param > Class Template Reference

CVODES ode data holder object which is used during CVODES integration for CVODES callbacks. More...

`#include <cvodes_ode_data.hpp>`

## Public Member Functions
| cvodes_ode_data (const F &f, const std::vector< T_initial > &y0, const std::vector< T_param > &theta, const std::vector< double > &x, const std::vector< int > &x_int, std::ostream *msgs)
| Construct CVODES ode data object to enable callbacks from CVODES during ODE integration. More...

## Static Public Member Functions
static int | ode_rhs (double t, N_Vector y, N_Vector ydot, void *user_data)
static int | ode_rhs_sens (int Ns, realtype t, N_Vector y, N_Vector ydot, N_Vector *yS, N_Vector *ySdot, void *user_data, N_Vector tmp1, N_Vector tmp2)
static int | dense_jacobian (long int N, realtype t, N_Vector y, N_Vector fy, DlsMat J, void *user_data, N_Vector tmp1, N_Vector tmp2, N_Vector tmp3)

## Detailed Description

### template<typename F, typename T_initial, typename T_param>
class stan::math::cvodes_ode_data< F, T_initial, T_param >

CVODES ode data holder object which is used during CVODES integration for CVODES callbacks.

Template Parameters

  F | type of functor for the base ode system.
  T_initial | type of initial values
  T_param | type of parameters

Definition at line 27 of file cvodes_ode_data.hpp.

## Constructor & Destructor Documentation

template<typename F , typename T_initial , typename T_param >

stan::math::cvodes_ode_data< F, T_initial, T_param >::cvodes_ode_data | ( | const F & | f,
|  | const std::vector< T_initial > & | y0,
|  | const std::vector< T_param > & | theta,
|  | const std::vector< double > & | x,
|  | const std::vector< int > & | x_int,
|  | std::ostream * | msgs
| ) |  |
| inline

Construct CVODES ode data object to enable callbacks from CVODES during ODE integration.

Static callbacks are defined for the ODE RHS (`ode_rhs`), the ODE sensitivity RHS (`ode_rhs_sens`) and for the ODE Jacobian wrt to the states (`dense_jacobian`).

Parameters

  [in] | f | ode functor.
  [in] | y0 | initial state of the base ode.
  [in] | theta | parameters of the base ode.
  [in] | x | continuous data vector for the ODE.
  [in] | x_int | integer data vector for the ODE.
  [in] | msgs | stream to which messages are printed.

Definition at line 53 of file cvodes_ode_data.hpp.

## Member Function Documentation

template<typename F , typename T_initial , typename T_param >

static int stan::math::cvodes_ode_data< F, T_initial, T_param >::dense_jacobian | ( | long int | N,
|  | realtype | t,
|  | N_Vector | y,
|  | N_Vector | fy,
|  | DlsMat | J,
|  | void * | user_data,
|  | N_Vector | tmp1,
|  | N_Vector | tmp2,
|  | N_Vector | tmp3
| ) |  |
| inlinestatic

Definition at line 85 of file cvodes_ode_data.hpp.

template<typename F , typename T_initial , typename T_param >

static int stan::math::cvodes_ode_data< F, T_initial, T_param >::ode_rhs | ( | double | t,
|  | N_Vector | y,
|  | N_Vector | ydot,
|  | void * | user_data
| ) |  |
| inlinestatic

Definition at line 66 of file cvodes_ode_data.hpp.

template<typename F , typename T_initial , typename T_param >

static int stan::math::cvodes_ode_data< F, T_initial, T_param >::ode_rhs_sens | ( | int | Ns,
|  | realtype | t,
|  | N_Vector | y,
|  | N_Vector | ydot,
|  | N_Vector * | yS,
|  | N_Vector * | ySdot,
|  | void * | user_data,
|  | N_Vector | tmp1,
|  | N_Vector | tmp2
| ) |  |
| inlinestatic

Definition at line 73 of file cvodes_ode_data.hpp.

The documentation for this class was generated from the following file:

- stan/math/rev/mat/functor/cvodes_ode_data.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.